==> alloy-ui-3.0.1.jar: META-INF/resources/webjars/alloy-ui/3.0.1/src/aui-image-viewer/HISTORY.md <==
# AUI Image Viewer

> Documentation and test modifications are not included in this changelog. For more details, see [full commit history](https://github.com/liferay/alloy-ui/commits/master/src/aui-image-viewer).

## @VERSION@

* [AUI-1669](https://issues.liferay.com/browse/AUI-1669) Image Viewer Base throws error when no images or sources are provided

## [3.0.0](https://github.com/liferay/alloy-ui/releases/tag/3.0.0)

* [AUI-1639](https://issues.liferay.com/browse/AUI-1639) Setting height/width in ImageViewer
* [AUI-1598](https://issues.liferay.com/browse/AUI-1598) Carousel should work with text and other contents
* [AUI-1593](https://issues.liferay.com/browse/AUI-1593) Removing ie8 hack on ImageViewerBase
* [AUI-1581](https://issues.liferay.com/browse/AUI-1581) AUI Carousel demo images don't appear in Firefox
* [AUI-1485](https://issues.liferay.com/browse/AUI-1485) aui-image-viewer HISTORY.md
* [AUI-1455](https://issues.liferay.com/browse/AUI-1455) Change listener method names on ImageViewer modules
* [AUI-1305](https://issues.liferay.com/browse/AUI-1305) Make aui-image-gallery responsive
* [AUI-1334](https://issues.liferay.com/browse/AUI-1334) Image viewer thumbnails link to wrong image
* [AUI-1318](https://issues.liferay.com/browse/AUI-1318) Make aui-image-viewer responsive
* [AUI-1287](https://issues.liferay.com/browse/AUI-1287) Wrong css formatting when running "grunt format"
* [AUI-1174](https://issues.liferay.com/browse/AUI-1174) Validate source code with JSHint
* [AUI-1098](https://issues.liferay.com/browse/AUI-1098) Upgrade to Bootstrap 3
* [AUI-1230](https://issues.liferay.com/browse/AUI-1230) Improve ImageGallery button alignment and general spacings on Bootstrap 3
* [AUI-1224](https://issues.liferay.com/browse/AUI-1224) Add .glyphicon and change prefix from .icon-* to .glyphicon-* on Bootstrap 3

## [2.5.0](https://github.com/liferay/alloy-ui/releases/tag/2.5.0)

* [AUI-1163](https://issues.liferay.com/browse/AUI-1163) Remove unnecessary constants
* [AUI-1175](https://issues.liferay.com/browse/AUI-1175) Long file names extend beyond viewer in Image Gallery Viewer
* [AUI-1106](https://issues.liferay.com/browse/AUI-1106) Image Viewer Gallery styling issues

==> alloy-ui-3.0.2.jar: META-INF/resources/webjars/alloy-ui/3.0.2/src/aui-image-viewer/HISTORY.md <==
# AUI Image Viewer

> Documentation and test modifications are not included in this changelog. For more details, see [full commit history](https://github.com/liferay/alloy-ui/commits/master/src/aui-image-viewer).

## @VERSION@

* [AUI-2044](https://issues.liferay.com/browse/AUI-2044) Add zIndex to AUI Image Viewer

## [3.0.1](https://github.com/liferay/alloy-ui/releases/tag/3.0.1)

* [AUI-1669](https://issues.liferay.com/browse/AUI-1669) Image Viewer Base throws error when no images or sources are provided

## [3.0.0](https://github.com/liferay/alloy-ui/releases/tag/3.0.0)

* [AUI-1639](https://issues.liferay.com/browse/AUI-1639) Setting height/width in ImageViewer
* [AUI-1598](https://issues.liferay.com/browse/AUI-1598) Carousel should work with text and other contents
* [AUI-1593](https://issues.liferay.com/browse/AUI-1593) Removing ie8 hack on ImageViewerBase
* [AUI-1581](https://issues.liferay.com/browse/AUI-1581) AUI Carousel demo images don't appear in Firefox
* [AUI-1485](https://issues.liferay.com/browse/AUI-1485) aui-image-viewer HISTORY.md
* [AUI-1455](https://issues.liferay.com/browse/AUI-1455) Change listener method names on ImageViewer modules
* [AUI-1305](https://issues.liferay.com/browse/AUI-1305) Make aui-image-gallery responsive
* [AUI-1334](https://issues.liferay.com/browse/AUI-1334) Image viewer thumbnails link to wrong image
* [AUI-1318](https://issues.liferay.com/browse/AUI-1318) Make aui-image-viewer responsive
* [AUI-1287](https://issues.liferay.com/browse/AUI-1287) Wrong css formatting when running "grunt format"
* [AUI-1174](https://issues.liferay.com/browse/AUI-1174) Validate source code with JSHint
* [AUI-1098](https://issues.liferay.com/browse/AUI-1098) Upgrade to Bootstrap 3
* [AUI-1230](https://issues.liferay.com/browse/AUI-1230) Improve ImageGallery button alignment and general spacings on Bootstrap 3
* [AUI-1224](https://issues.liferay.com/browse/AUI-1224) Add .glyphicon and change prefix from .icon-* to .glyphicon-* on Bootstrap 3

## [2.5.0](https://github.com/liferay/alloy-ui/releases/tag/2.5.0)

* [AUI-1163](https://issues.liferay.com/browse/AUI-1163) Remove unnecessary constants
* [AUI-1175](https://issues.liferay.com/browse/AUI-1175) Long file names extend beyond viewer in Image Gallery Viewer
* [AUI-1106](https://issues.liferay.com/browse/AUI-1106) Image Viewer Gallery styling issues
